%define major	3
%define libname	%mklibname %{name} %{major}
%define	devname	%mklibname -d %{name}

Name:		bluez
Summary:	Official Linux Bluetooth protocol stack
Version:	4.101
Release:	%mkrel 5
License:	GPLv2+
Group:		Communications/Bluetooth
URL:		http://bluez.org/
Source0:	http://www.kernel.org/pub/linux/bluetooth/%{name}-%{version}.tar.xz
Source6:	pand.conf
Source7:	dund.conf
Source8:	hidd.conf
Source9:	rfcomm.conf

# (cg) Mageia+Friends Patches
Patch0500:	0500-Add-support-for-CF-Personal-Network-Card-Rev-2.5-fro.patch
Patch0501:	0501-Add-sixaxis-cable-pairing-plugin.patch
Patch0502:	0502-systemd-Use-standard-argument-name-for-systemd.patch
Patch0503:	0503-systemd-Fix-unit-to-correct-path-to-bluetoothd.patch
Patch0504:	bluez-4.101-automake-1.13.patch


BuildRequires:	dbus-devel
BuildRequires:	flex
BuildRequires:	bison
BuildRequires:	libusb-devel
BuildRequires:	libalsa-devel
BuildRequires:	readline-devel
BuildRequires:	udev
BuildRequires:	libgstreamer0.10-plugins-base-devel
BuildRequires:	gstreamer0.10-devel
BuildRequires:	expat-devel
BuildRequires:	udev-devel
BuildRequires:	libcap-ng-devel
BuildRequires:	pkgconfig(systemd)
# for simple-agent
Requires:	python-gobject
Requires:	bluez-pin
Requires:	obex-data-server
Requires(pre):	filesystem >= 2.1.9-18
Requires(post):	rpm-helper >= 0.24.8-1
Requires(preun):	rpm-helper >= 0.24.8-1
Suggests:	bluez-firmware

%description
These are the official Bluetooth communication libraries for Linux.

%post
update-alternatives --install /bin/bluepin bluepin /usr/bin/bluepin 5
#migrate old configuration
if [ "$1" = "2" -a -d %{_var}/lib/lib/bluetooth ]; then
 mv -f %{_var}/lib/lib/bluetooth/* %{_var}/lib/bluetooth/ > /dev/null 2>&1 || exit 0
 rmdir %{_var}/lib/lib/bluetooth/ > /dev/null 2>&1 || exit 0
 rmdir %{_var}/lib/lib/ > /dev/null 2>&1 || exit 0
fi
%_post_service bluetooth

%postun
if [ "$1" = "0" ]; then
  update-alternatives --remove bluepin /usr/bin/bluepin
fi

%files
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man?/*
%exclude %{_mandir}/man8/hid2hci.8*
%config(noreplace) %{_sysconfdir}/sysconfig/*
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/*.conf
%config(noreplace) %{_sysconfdir}/bluetooth
/lib/udev/bluetooth_serial
/lib/udev/rules.d/97-bluetooth-serial.rules
%{_localstatedir}/lib/bluetooth
%{_unitdir}/bluetooth.service
%{_datadir}/dbus-1/system-services/org.bluez.service

#--------------------------------------------------------------------

%package        cups
Summary:        CUPS printer backend for Bluetooth printers
Group:          System/Printing
Requires:       cups

%description    cups
This package contains the CUPS backend for Bluetooth printers.

%files cups
%{_prefix}/lib/cups/backend/bluetooth

#--------------------------------------------------------------------

%package gstreamer
Summary: Gstreamer support for SBC audio format
Group: Sound/Mixers

%description gstreamer
This package contains gstreamer plugins for the Bluetooth SBC audio format

%files gstreamer
%{_libdir}/gstreamer-*/*.so

#--------------------------------------------------------------------

%package alsa
Summary: ALSA support for Bluetooth audio devices
Group: Sound/Mixers

%description alsa
This package contains ALSA support for Bluetooth audio devices

%files alsa
%{_libdir}/alsa-lib/*.so
%{_datadir}/alsa/bluetooth.conf

#--------------------------------------------------------------------

%package hid2hci
Summary: Put HID proxying bluetooth HCI's into HCI mode
Group: Communications/Bluetooth
Conflicts: %{name} < 4.99-1
Requires(post): filesystem >= 2.1.9-18

%description hid2hci
Most allinone PC's and bluetooth keyboard / mouse sets which include a
bluetooth dongle, ship with a so called HID proxying bluetooth HCI.
The HID proxying makes the keyboard / mouse show up as regular USB HID
devices (after connecting using the connect button on the device + keyboard),
which makes them work without requiring any manual configuration.

The bluez-hid2hci package contains the hid2hci utility and udev rules to
automatically switch supported Bluetooth devices into regular HCI mode.

Install this package if you want to use the bluetooth function of the HCI
with other bluetooth devices like for example a mobile phone.

Note that after installing this package you will first need to pair your
bluetooth keyboard and mouse with the bluetooth adapter before you can use
them again. Since you cannot use your bluetooth keyboard and mouse until
they are paired, this will require the use of a regular (wired) USB keyboard
and mouse.

%files hid2hci
/lib/udev/hid2hci
/lib/udev/rules.d/97-bluetooth-hid2hci.rules
%{_mandir}/man8/hid2hci.8*

%post hid2hci
%{_bindir}/udevadm trigger --subsystem-match=usb

#--------------------------------------------------------------------

%package -n	%{libname}
Summary:	Official Linux Bluetooth protocol stack
Group:		System/Libraries
Requires(pre):	filesystem >= 2.1.9-18

%description -n	%{libname}
These are the official Bluetooth communication libraries for Linux.

%files -n %{libname}
%{_libdir}/lib*.so.%{major}*

#--------------------------------------------------------------------

%package -n	%{devname}
Summary:	Headers for developing programs that will use %name
Group:		Development/C++
Requires(pre):	filesystem >= 2.1.9-18
Requires:	%{libname} = %{version}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devname}
This package contains the headers that programmers will need to develop
applications which will use libraries from %{name}.

%files -n %{devname}
%doc AUTHORS ChangeLog README
%dir %{_includedir}/bluetooth
%{_includedir}/bluetooth/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/bluez.pc

#--------------------------------------------------------------------

%prep
%setup -q -n %name-%{version}
%apply_patches

%build
autoreconf -fi
# fix mdv bug 35444
%define _localstatedir %{_var}
%configure2_5x \
    --enable-cups \
    --enable-dfutool \
    --enable-tools \
    --enable-bccmd \
    --enable-gstreamer \
    --enable-hidd \
    --enable-pand \
    --enable-dund \
    --enable-hid2hci \
    --enable-pcmcia \
    --enable-udevrules \
    --enable-capng \
    --with-systemdsystemunitdir=%{_unitdir}

%make

%install
%makeinstall_std rulesdir=/lib/udev/rules.d udevdir=/lib/udev


#mkdir -p %{buildroot}%{_libdir}
#mv %{buildroot}/%{_lib}/gstreamer-0.10 %{buildroot}%{_libdir}

echo "1234" > %{buildroot}%{_sysconfdir}/bluetooth/pin

chmod 600 %{buildroot}%{_sysconfdir}/bluetooth/pin

rm -f %{buildroot}/etc/default/bluetooth %{buildroot}/etc/init.d/bluetooth
for a in dund hidd pand ; do
    install -D -m0644 $RPM_SOURCE_DIR/$a.conf %{buildroot}%{_sysconfdir}/sysconfig/$a
done

rm -rf %{buildroot}/%{_lib}/pkgconfig
install -m644 bluez.pc -D  %{buildroot}%{_libdir}/pkgconfig/bluez.pc


# Remove the cups backend from libdir, and install it in /usr/lib whatever the install
%ifarch x86_64
if test -d %{buildroot}%{_libdir}/cups ; then
    install -D -m0755 %{buildroot}%{_libdir}/cups/backend/bluetooth %{buildroot}/usr/lib/cups/backend/bluetooth
    rm -rf %{buildroot}%{_libdir}/cups
fi 
%endif

# (cg) can we drop this move+symlink?
mkdir -p %{buildroot}%{_sbindir}
mv %{buildroot}%{_bindir}/hidd %{buildroot}%{_sbindir}
ln -s %{_sbindir}/hidd %{buildroot}%{_bindir}/hidd

cp test/test-* %{buildroot}%{_bindir}
cp test/simple-agent %{buildroot}%{_bindir}/simple-agent

#install -D -m0755 %{SOURCE10} %{buildroot}/sbin/udev_bluetooth_helper
#install -D -m0644 %{SOURCE11} %{buildroot}%{_sysconfdir}/udev/rules.d/60-bluetooth.rules

#install more config files
install -m0644 audio/audio.conf %{buildroot}%{_sysconfdir}/bluetooth/
install -m0644 network/network.conf %{buildroot}%{_sysconfdir}/bluetooth/
install -m0644 input/input.conf %{buildroot}%{_sysconfdir}/bluetooth/
install -m0644 serial/serial.conf %{buildroot}%{_sysconfdir}/bluetooth/

#%__mkdir -p %{buildroot}%{_libdir}/alsa-lib/
#%__mv %{buildroot}/%{_lib}/alsa-lib/*.so %{buildroot}%{_libdir}/alsa-lib/

# remove unpackaged files
find %{buildroot} -name '*.la' -delete

install -d -m0755 %{buildroot}/%{_localstatedir}/lib/bluetooth


%changelog

* Fri Jan 11 2013 umeabot <umeabot> 4.101-5.mga3
+ Revision: 346925
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 29 2012 cjw <cjw> 4.101-4.mga3
+ Revision: 336270
- patch0504: fix build with automake 1.13

* Wed Oct 03 2012 malo <malo> 4.101-3.mga3
+ Revision: 302586
- update RPM group

* Sat Jul 21 2012 colin <colin> 4.101-2.mga3
+ Revision: 273158
- Update for usrmove

* Fri Jun 29 2012 colin <colin> 4.101-1.mga3
+ Revision: 265009
- New version: 4.101
- Drop sysvinit only udev rule.
- Rebase patches (thanks to Fedora for updated sixaxis patch)
- Fix Build Requires
- Rebuild against new libudev major

* Sat Apr 28 2012 tmb <tmb> 4.99-3.mga2
+ Revision: 233611
- Require rpm-helper >= 0.24.8-1 for systemd support

* Fri Apr 27 2012 tmb <tmb> 4.99-2.mga2
+ Revision: 233515
- rebuild for versioned rpm-helper requires

* Sun Apr 08 2012 colin <colin> 4.99-1.mga2
+ Revision: 229743
- Split hid2hci into a subpackage to make it optional
- New version: 4.99

* Tue Mar 06 2012 colin <colin> 4.98-2.mga2
+ Revision: 219435
- Fix C++ build problems in bluetooth.h
- Fix obexd build problems in bluetooth.h
- Split up systemd patches for (hopefully) future upstreaming
- Prevent double logging in systemd journal

* Mon Mar 05 2012 colin <colin> 4.98-1.mga2
+ Revision: 219189
- New version 4.98
- Rediff patches
- Rewrite systemd patch to fixup committed systemd support.

  + dmorgan <dmorgan>
    - Remove %%_postun_service macro, this is now handled by filetriggers

* Sat Dec 24 2011 dmorgan <dmorgan> 4.96-5.mga2
+ Revision: 187180
- Fix systemd support

* Sat Dec 24 2011 dmorgan <dmorgan> 4.96-4.mga2
+ Revision: 187168
- Handle systemd services at install now ( mga #3867)

* Sat Dec 17 2011 colin <colin> 4.96-3.mga2
+ Revision: 183014
- Add patches from Fedora for device compatibiliy + systemd integration.
- Move udev rules to /lib/udev/rules.d rather than /etc/
- Fix some minor space+tab inconsistencies in spec
- Do not copy binaries to /sbin but move+link them (should go away when dracut is mandatory)

* Mon Dec 05 2011 fwang <fwang> 4.96-2.mga2
+ Revision: 176816
- new version 4.96
- drop all .la files
- br systemd
- br readline
- new version 4.95

  + colin <colin>
    - New version: 4.96 (fixed 100%% CPU on bluetoothd)
    - Drop hal BR. No longer needed

  + misc <misc>
    - fix systemd patch, taken from Mandriva, made by Funda wang
    - new version 4.94
    - remove old obsoletes ( likely no longer needed )
    - remove old %%clean section
    - clean %%defattr, clean old comments
    - remove obsoletes dating back to october 2008
    - fix requires

* Wed Apr 27 2011 mikala <mikala> 4.92-1.mga1
+ Revision: 92032
- Update tarball to 4.92

* Mon Apr 18 2011 misc <misc> 4.91-1.mga1
+ Revision: 87663
- update to 4.91

* Sat Feb 26 2011 eandry <eandry> 4.89-1.mga1
+ Revision: 60766
- New version 4.89

* Sun Jan 30 2011 dmorgan <dmorgan> 4.87-1.mga1
+ Revision: 44751
- Fix patch 101
- Merge mdv commits :
  634082
  634090
  634124
- Update to version 4.87

* Sat Jan 15 2011 blino <blino> 4.79-2.mga1
+ Revision: 18786
- remove old trigger

  + eandry <eandry>
    - imported package bluez

